@@ -26,54 +26,66 @@
 namespace grpc_core {
 namespace chaotic_good {
 
+// Remember to add new frame types to frame_fuzzer.cc
 enum class FrameType : uint8_t {
   kSettings = 0x00,
-  kFragment = 0x80,
-  kCancel = 0x81,
+  kClientInitialMetadata = 0x80,
+  kClientEndOfStream = 0x81,
+  kServerInitialMetadata = 0x91,
+  kServerTrailingMetadata = 0x92,
+  kMessage = 0xa0,
+  kBeginMessage = 0xa1,
+  kMessageChunk = 0xa2,
+  kCancel = 0xff,
 };
 
+std::string FrameTypeString(FrameType type);
+
 inline std::ostream& operator<<(std::ostream& out, FrameType type) {
-  switch (type) {
-    case FrameType::kSettings:
-      return out << "Settings";
-    case FrameType::kFragment:
-      return out << "Fragment";
-    case FrameType::kCancel:
-      return out << "Cancel";
-    default:
-      return out << "Unknown[" << static_cast<int>(type) << "]";
-  }
+  return out << FrameTypeString(type);
+}
+
+template <typename Sink>
+void AbslStringify(Sink& sink, FrameType type) {
+  sink.Append(FrameTypeString(type));
 }
 
 struct FrameHeader {
   FrameType type = FrameType::kCancel;
-  BitSet<3> flags;
+  uint16_t payload_connection_id = 0;
   uint32_t stream_id = 0;
-  uint32_t header_length = 0;
-  uint32_t message_length = 0;
-  uint32_t message_padding = 0;
-  uint32_t trailer_length = 0;
+  uint32_t payload_length = 0;
 
-  // Parses a frame header from a buffer of 24 bytes. All 24 bytes are consumed.
+  // Parses a frame header from a buffer of 12 bytes. All 12 bytes are consumed.
   static absl::StatusOr<FrameHeader> Parse(const uint8_t* data);
-  // Serializes a frame header into a buffer of 24 bytes.
+  // Serializes a frame header into a buffer of 12 bytes.
   void Serialize(uint8_t* data) const;
-  // Compute frame sizes from the header.
-  uint32_t GetFrameLength() const;
   // Report contents as a string
   std::string ToString() const;
+  // Required padding to maintain alignment.
+  uint32_t Padding(uint32_t alignment) const {
+    if (payload_connection_id == 0) {
+      return 0;
+    }
+    if (payload_length % alignment == 0) {
+      return 0;
+    }
+    return alignment - (payload_length % alignment);
+  }
 
   bool operator==(const FrameHeader& h) const {
-    return type == h.type && flags == h.flags && stream_id == h.stream_id &&
-           header_length == h.header_length &&
-           message_length == h.message_length &&
-           message_padding == h.message_padding &&
-           trailer_length == h.trailer_length;
+    return type == h.type && stream_id == h.stream_id &&
+           payload_connection_id == h.payload_connection_id &&
+           payload_length == h.payload_length;
   }
-  // Frame header size is fixed to 24 bytes.
-  static constexpr size_t kFrameHeaderSize = 24;
+  // Frame header size is fixed to 12 bytes.
+  enum { kFrameHeaderSize = 12 };
 };
 
+inline std::ostream& operator<<(std::ostream& out, const FrameHeader& h) {
+  return out << h.ToString();
+}
+
 }  // namespace chaotic_good
 }  // namespace grpc_core
 
