@@ -14,6 +14,8 @@
 
 #include "src/core/lib/security/authorization/evaluate_args.h"
 
+#include <grpc/grpc_security_constants.h>
+#include <grpc/support/port_platform.h>
 #include <string.h>
 
 #include "absl/log/log.h"
@@ -21,16 +23,12 @@
 #include "absl/status/statusor.h"
 #include "absl/strings/match.h"
 #include "absl/strings/numbers.h"
-
-#include <grpc/grpc_security_constants.h>
-#include <grpc/support/port_platform.h>
-
 #include "src/core/handshaker/endpoint_info/endpoint_info_handshaker.h"
 #include "src/core/lib/address_utils/parse_address.h"
-#include "src/core/lib/gprpp/host_port.h"
 #include "src/core/lib/security/credentials/tls/tls_utils.h"
 #include "src/core/lib/slice/slice.h"
-#include "src/core/lib/uri/uri_parser.h"
+#include "src/core/util/host_port.h"
+#include "src/core/util/uri.h"
 
 namespace grpc_core {
 
@@ -117,13 +115,13 @@ absl::string_view EvaluateArgs::GetMethod() const {
   return absl::string_view();
 }
 
-absl::optional<absl::string_view> EvaluateArgs::GetHeaderValue(
+std::optional<absl::string_view> EvaluateArgs::GetHeaderValue(
     absl::string_view key, std::string* concatenated_value) const {
   if (metadata_ == nullptr) {
-    return absl::nullopt;
+    return std::nullopt;
   }
   if (absl::EqualsIgnoreCase(key, "te")) {
-    return absl::nullopt;
+    return std::nullopt;
   }
   if (absl::EqualsIgnoreCase(key, "host")) {
     // Maps legacy host header to :authority.
