@@ -18,15 +18,14 @@
 
 #include "src/core/lib/transport/error_utils.h"
 
+#include <grpc/support/port_platform.h>
+#include <grpc/support/string_util.h>
 #include <stdint.h>
 
 #include <vector>
 
-#include <grpc/support/port_platform.h>
-#include <grpc/support/string_util.h>
-
-#include "src/core/lib/gprpp/status_helper.h"
 #include "src/core/lib/transport/status_conversion.h"
+#include "src/core/util/status_helper.h"
 
 static grpc_error_handle recursively_find_error_with_field(
     grpc_error_handle error, grpc_core::StatusIntProperty which) {
