@@ -20,12 +20,13 @@
 
 #include <grpc/support/alloc.h>
 
+#include <optional>
+
 #include "absl/status/status.h"
-#include "absl/types/optional.h"
 #include "gtest/gtest.h"
+#include "src/core/config/core_configuration.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/channel/channel_args_preconditioning.h"
-#include "src/core/lib/config/core_configuration.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
 #include "src/core/util/status_helper.h"
 #include "test/core/test_util/test_config.h"
