@@ -15,11 +15,10 @@
 #include <memory>
 
 #include "gtest/gtest.h"
-
 #include "src/core/lib/channel/channel_args.h"
-#include "src/core/lib/gprpp/crash.h"
 #include "src/core/lib/resource_quota/arena.h"
 #include "src/core/telemetry/call_tracer.h"
+#include "src/core/util/crash.h"
 
 namespace grpc_core {
 namespace {
