@@ -25,7 +25,7 @@
 
 namespace grpc_core {
 
-CORE_END2END_TEST(CoreEnd2endTest, CancelBeforeInvoke6) {
+CORE_END2END_TEST(CoreEnd2endTests, CancelBeforeInvoke6) {
   auto c = NewClientCall("/service/method").Create();
   c.Cancel();
   IncomingStatusOnClient server_status;
@@ -43,7 +43,7 @@ CORE_END2END_TEST(CoreEnd2endTest, CancelBeforeInvoke6) {
   EXPECT_EQ(server_status.status(), GRPC_STATUS_CANCELLED);
 }
 
-CORE_END2END_TEST(CoreEnd2endTest, CancelBeforeInvoke5) {
+CORE_END2END_TEST(CoreEnd2endTests, CancelBeforeInvoke5) {
   auto c = NewClientCall("/service/method").Create();
   c.Cancel();
   IncomingStatusOnClient server_status;
@@ -59,7 +59,7 @@ CORE_END2END_TEST(CoreEnd2endTest, CancelBeforeInvoke5) {
   EXPECT_EQ(server_status.status(), GRPC_STATUS_CANCELLED);
 }
 
-CORE_END2END_TEST(CoreEnd2endTest, CancelBeforeInvoke4) {
+CORE_END2END_TEST(CoreEnd2endTests, CancelBeforeInvoke4) {
   auto c = NewClientCall("/service/method").Create();
   c.Cancel();
   IncomingStatusOnClient server_status;
@@ -73,7 +73,7 @@ CORE_END2END_TEST(CoreEnd2endTest, CancelBeforeInvoke4) {
   EXPECT_EQ(server_status.status(), GRPC_STATUS_CANCELLED);
 }
 
-CORE_END2END_TEST(CoreEnd2endTest, CancelBeforeInvoke3) {
+CORE_END2END_TEST(CoreEnd2endTests, CancelBeforeInvoke3) {
   auto c = NewClientCall("/service/method").Create();
   c.Cancel();
   IncomingStatusOnClient server_status;
@@ -86,7 +86,7 @@ CORE_END2END_TEST(CoreEnd2endTest, CancelBeforeInvoke3) {
   EXPECT_EQ(server_status.status(), GRPC_STATUS_CANCELLED);
 }
 
-CORE_END2END_TEST(CoreEnd2endTest, CancelBeforeInvoke2) {
+CORE_END2END_TEST(CoreEnd2endTests, CancelBeforeInvoke2) {
   auto c = NewClientCall("/service/method").Create();
   c.Cancel();
   IncomingStatusOnClient server_status;
@@ -96,7 +96,7 @@ CORE_END2END_TEST(CoreEnd2endTest, CancelBeforeInvoke2) {
   EXPECT_EQ(server_status.status(), GRPC_STATUS_CANCELLED);
 }
 
-CORE_END2END_TEST(CoreEnd2endTest, CancelBeforeInvoke1) {
+CORE_END2END_TEST(CoreEnd2endTests, CancelBeforeInvoke1) {
   auto c = NewClientCall("/service/method").Create();
   c.Cancel();
   IncomingStatusOnClient server_status;
