@@ -290,14 +290,14 @@ class TestConfigurator {
       GRPC_COMPRESS_NONE;
 };
 
-CORE_END2END_TEST(Http2SingleHopTest, DisabledAlgorithmDecompressInCore) {
+CORE_END2END_TEST(Http2SingleHopTests, DisabledAlgorithmDecompressInCore) {
   TestConfigurator(*this)
       .ClientDefaultAlgorithm(GRPC_COMPRESS_GZIP)
       .DisableAlgorithmAtServer(GRPC_COMPRESS_GZIP)
       .DisabledAlgorithmTest();
 }
 
-CORE_END2END_TEST(Http2SingleHopTest, DisabledAlgorithmDecompressInApp) {
+CORE_END2END_TEST(Http2SingleHopTests, DisabledAlgorithmDecompressInApp) {
   TestConfigurator(*this)
       .ClientDefaultAlgorithm(GRPC_COMPRESS_GZIP)
       .DisableAlgorithmAtServer(GRPC_COMPRESS_GZIP)
@@ -305,7 +305,7 @@ CORE_END2END_TEST(Http2SingleHopTest, DisabledAlgorithmDecompressInApp) {
       .DisabledAlgorithmTest();
 }
 
-CORE_END2END_TEST(Http2SingleHopTest,
+CORE_END2END_TEST(Http2SingleHopTests,
                   RequestWithExceptionallyUncompressedPayloadDecompressInCore) {
   TestConfigurator(*this)
       .ClientDefaultAlgorithm(GRPC_COMPRESS_GZIP)
@@ -313,7 +313,7 @@ CORE_END2END_TEST(Http2SingleHopTest,
       .RequestWithPayload(GRPC_WRITE_NO_COMPRESS, {});
 }
 
-CORE_END2END_TEST(Http2SingleHopTest,
+CORE_END2END_TEST(Http2SingleHopTests,
                   RequestWithExceptionallyUncompressedPayloadDecompressInApp) {
   TestConfigurator(*this)
       .ClientDefaultAlgorithm(GRPC_COMPRESS_GZIP)
@@ -323,17 +323,17 @@ CORE_END2END_TEST(Http2SingleHopTest,
       .RequestWithPayload(GRPC_WRITE_NO_COMPRESS, {});
 }
 
-CORE_END2END_TEST(Http2SingleHopTest,
+CORE_END2END_TEST(Http2SingleHopTests,
                   RequestWithUncompressedPayloadDecompressInCore) {
   TestConfigurator(*this).RequestWithPayload(0, {});
 }
 
-CORE_END2END_TEST(Http2SingleHopTest,
+CORE_END2END_TEST(Http2SingleHopTests,
                   RequestWithUncompressedPayloadDecompressInApp) {
   TestConfigurator(*this).DecompressInApp().RequestWithPayload(0, {});
 }
 
-CORE_END2END_TEST(Http2SingleHopTest,
+CORE_END2END_TEST(Http2SingleHopTests,
                   RequestWithCompressedPayloadDecompressInCore) {
   TestConfigurator(*this)
       .ClientDefaultAlgorithm(GRPC_COMPRESS_GZIP)
@@ -341,7 +341,7 @@ CORE_END2END_TEST(Http2SingleHopTest,
       .RequestWithPayload(0, {});
 }
 
-CORE_END2END_TEST(Http2SingleHopTest,
+CORE_END2END_TEST(Http2SingleHopTests,
                   RequestWithCompressedPayloadDecompressInApp) {
   TestConfigurator(*this)
       .ClientDefaultAlgorithm(GRPC_COMPRESS_GZIP)
@@ -352,7 +352,7 @@ CORE_END2END_TEST(Http2SingleHopTest,
       .RequestWithPayload(0, {});
 }
 
-CORE_END2END_TEST(Http2SingleHopTest,
+CORE_END2END_TEST(Http2SingleHopTests,
                   RequestWithSendMessageBeforeInitialMetadataDecompressInCore) {
   TestConfigurator(*this)
       .ClientDefaultAlgorithm(GRPC_COMPRESS_GZIP)
@@ -360,7 +360,7 @@ CORE_END2END_TEST(Http2SingleHopTest,
       .RequestWithSendMessageBeforeInitialMetadata();
 }
 
-CORE_END2END_TEST(Http2SingleHopTest,
+CORE_END2END_TEST(Http2SingleHopTests,
                   RequestWithSendMessageBeforeInitialMetadataDecompressInApp) {
   TestConfigurator(*this)
       .ClientDefaultAlgorithm(GRPC_COMPRESS_GZIP)
@@ -371,11 +371,11 @@ CORE_END2END_TEST(Http2SingleHopTest,
       .RequestWithSendMessageBeforeInitialMetadata();
 }
 
-CORE_END2END_TEST(Http2SingleHopTest, RequestWithServerLevelDecompressInCore) {
+CORE_END2END_TEST(Http2SingleHopTests, RequestWithServerLevelDecompressInCore) {
   TestConfigurator(*this).RequestWithServerLevel(GRPC_COMPRESS_LEVEL_HIGH);
 }
 
-CORE_END2END_TEST(Http2SingleHopTest, RequestWithServerLevelDecompressInApp) {
+CORE_END2END_TEST(Http2SingleHopTests, RequestWithServerLevelDecompressInApp) {
   TestConfigurator(*this)
       .DecompressInApp()
       .ExpectedAlgorithmFromServer(GRPC_COMPRESS_DEFLATE)
@@ -383,14 +383,14 @@ CORE_END2END_TEST(Http2SingleHopTest, RequestWithServerLevelDecompressInApp) {
 }
 
 CORE_END2END_TEST(
-    Http2SingleHopTest,
+    Http2SingleHopTests,
     RequestWithCompressedPayloadMetadataOverrideNoneToGzipDecompressInCore) {
   TestConfigurator(*this).RequestWithPayload(
       0, {{"grpc-internal-encoding-request", "gzip"}});
 }
 
 CORE_END2END_TEST(
-    Http2SingleHopTest,
+    Http2SingleHopTests,
     RequestWithCompressedPayloadMetadataOverrideNoneToGzipDecompressInApp) {
   TestConfigurator(*this)
       .DecompressInApp()
@@ -399,7 +399,7 @@ CORE_END2END_TEST(
 }
 
 CORE_END2END_TEST(
-    Http2SingleHopTest,
+    Http2SingleHopTests,
     RequestWithCompressedPayloadMetadataOverrideDeflateToGzipDecompressInCore) {
   TestConfigurator(*this)
       .ClientDefaultAlgorithm(GRPC_COMPRESS_DEFLATE)
@@ -407,7 +407,7 @@ CORE_END2END_TEST(
 }
 
 CORE_END2END_TEST(
-    Http2SingleHopTest,
+    Http2SingleHopTests,
     RequestWithCompressedPayloadMetadataOverrideDeflateToGzipDecompressInApp) {
   TestConfigurator(*this)
       .ClientDefaultAlgorithm(GRPC_COMPRESS_DEFLATE)
@@ -417,7 +417,7 @@ CORE_END2END_TEST(
 }
 
 CORE_END2END_TEST(
-    Http2SingleHopTest,
+    Http2SingleHopTests,
     RequestWithCompressedPayloadMetadataOverrideDeflateToIdentityDecompressInCore) {
   TestConfigurator(*this)
       .ClientDefaultAlgorithm(GRPC_COMPRESS_DEFLATE)
@@ -425,7 +425,7 @@ CORE_END2END_TEST(
 }
 
 CORE_END2END_TEST(
-    Http2SingleHopTest,
+    Http2SingleHopTests,
     RequestWithCompressedPayloadMetadataOverrideDeflateToIdentityDecompressInApp) {
   TestConfigurator(*this)
       .ClientDefaultAlgorithm(GRPC_COMPRESS_DEFLATE)
