@@ -24,10 +24,10 @@
 
 #include "absl/status/status.h"
 #include "gtest/gtest.h"
+#include "src/core/config/core_configuration.h"
 #include "src/core/lib/channel/channel_fwd.h"
 #include "src/core/lib/channel/channel_stack.h"
 #include "src/core/lib/channel/promise_based_filter.h"
-#include "src/core/lib/config/core_configuration.h"
 #include "src/core/lib/iomgr/closure.h"
 #include "src/core/lib/iomgr/error.h"
 #include "src/core/lib/promise/arena_promise.h"
@@ -82,7 +82,7 @@ const NoInterceptor TestFilter::Call::OnFinalize;
 const grpc_channel_filter TestFilter::kFilter =
     MakePromiseBasedFilter<TestFilter, FilterEndpoint::kServer>();
 
-CORE_END2END_TEST(CoreEnd2endTest, FilterCausesClose) {
+CORE_END2END_TEST(CoreEnd2endTests, FilterCausesClose) {
   CoreConfiguration::RegisterBuilder([](CoreConfiguration::Builder* builder) {
     builder->channel_init()->RegisterFilter<TestFilter>(GRPC_SERVER_CHANNEL);
   });
