@@ -12,6 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+#include <grpc/credentials.h>
+#include <grpc/grpc.h>
+#include <grpc/grpc_security.h>
+#include <grpc/grpc_security_constants.h>
+
 #include <string>
 #include <utility>
 
@@ -20,16 +25,8 @@
 #include "absl/strings/string_view.h"
 #include "gmock/gmock.h"
 #include "gtest/gtest.h"
-
-#include <grpc/credentials.h>
-#include <grpc/grpc.h>
-#include <grpc/grpc_security.h>
-#include <grpc/grpc_security_constants.h>
-
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/channel/promise_based_filter.h"
-#include "src/core/lib/gprpp/ref_counted_ptr.h"
-#include "src/core/lib/gprpp/unique_type_name.h"
 #include "src/core/lib/promise/arena_promise.h"
 #include "src/core/lib/promise/promise.h"
 #include "src/core/lib/security/context/security_context.h"
@@ -39,6 +36,8 @@
 #include "src/core/lib/security/transport/auth_filters.h"
 #include "src/core/lib/transport/metadata_batch.h"
 #include "src/core/lib/transport/transport.h"
+#include "src/core/util/ref_counted_ptr.h"
+#include "src/core/util/unique_type_name.h"
 #include "src/core/util/useful.h"
 #include "test/core/filters/filter_test.h"
 
@@ -58,6 +57,8 @@ class ClientAuthFilterTest : public FilterTest<ClientAuthFilter> {
         : grpc_call_credentials(GRPC_SECURITY_NONE),
           status_(std::move(status)) {}
 
+    void Orphaned() override {}
+
     UniqueTypeName type() const override {
       static UniqueTypeName::Factory kFactory("FailCallCreds");
       return kFactory.Create();
