@@ -18,16 +18,15 @@
 
 #include "src/core/lib/iomgr/combiner.h"
 
-#include <thread>
-
-#include <gtest/gtest.h>
-
 #include <grpc/grpc.h>
 #include <grpc/support/alloc.h>
+#include <gtest/gtest.h>
 
-#include "src/core/lib/gprpp/crash.h"
-#include "src/core/lib/gprpp/notification.h"
-#include "src/core/lib/gprpp/thd.h"
+#include <thread>
+
+#include "src/core/util/crash.h"
+#include "src/core/util/notification.h"
+#include "src/core/util/thd.h"
 #include "src/core/util/useful.h"
 #include "test/core/test_util/test_config.h"
 
