@@ -18,13 +18,13 @@
 #include <stdlib.h>
 
 #include <memory>
+#include <optional>
 #include <string>
 #include <vector>
 
 #include "absl/strings/match.h"
 #include "absl/strings/str_cat.h"
 #include "absl/strings/str_split.h"
-#include "absl/types/optional.h"
 #include "gtest/gtest.h"
 #include "src/core/lib/resource_quota/arena.h"
 #include "src/core/lib/resource_quota/memory_quota.h"
@@ -61,7 +61,7 @@ TEST(MetadataMapTest, NoopWithDeadline) { TimeoutOnlyMetadataMap(); }
 TEST(MetadataMapTest, SimpleOps) {
   TimeoutOnlyMetadataMap map;
   EXPECT_EQ(map.get_pointer(GrpcTimeoutMetadata()), nullptr);
-  EXPECT_EQ(map.get(GrpcTimeoutMetadata()), absl::nullopt);
+  EXPECT_EQ(map.get(GrpcTimeoutMetadata()), std::nullopt);
   map.Set(GrpcTimeoutMetadata(),
           Timestamp::FromMillisecondsAfterProcessEpoch(1234));
   EXPECT_NE(map.get_pointer(GrpcTimeoutMetadata()), nullptr);
@@ -71,7 +71,7 @@ TEST(MetadataMapTest, SimpleOps) {
             Timestamp::FromMillisecondsAfterProcessEpoch(1234));
   map.Remove(GrpcTimeoutMetadata());
   EXPECT_EQ(map.get_pointer(GrpcTimeoutMetadata()), nullptr);
-  EXPECT_EQ(map.get(GrpcTimeoutMetadata()), absl::nullopt);
+  EXPECT_EQ(map.get(GrpcTimeoutMetadata()), std::nullopt);
 }
 
 // Target for MetadataMap::Encode.
