@@ -33,7 +33,9 @@
 #include "src/proto/grpc/gcp/altscontext.upb.h"
 #include "test/core/test_util/test_config.h"
 #include "test/core/tsi/alts/handshaker/alts_handshaker_service_api_test_lib.h"
+#include "upb/base/string_view.h"
 #include "upb/mem/arena.hpp"
+#include "upb/message/internal/map.h"
 
 #define ALTS_TSI_HANDSHAKER_TEST_RECV_BYTES "Hello World"
 #define ALTS_TSI_HANDSHAKER_TEST_OUT_FRAME "Hello Google"
@@ -359,26 +361,26 @@ static void on_client_next_success_cb(tsi_result status, void* user_data,
   ASSERT_EQ(memcmp(ALTS_TSI_HANDSHAKER_TEST_LOCAL_IDENTITY, local_account.data,
                    local_account.size),
             0);
-  size_t iter = kUpb_Map_Begin;
-  grpc_gcp_AltsContext_PeerAttributesEntry* peer_attributes_entry =
-      grpc_gcp_AltsContext_peer_attributes_nextmutable(ctx, &iter);
-  ASSERT_NE(peer_attributes_entry, nullptr);
-  while (peer_attributes_entry != nullptr) {
-    upb_StringView key = grpc_gcp_AltsContext_PeerAttributesEntry_key(
-        const_cast<grpc_gcp_AltsContext_PeerAttributesEntry*>(
-            peer_attributes_entry));
-    upb_StringView val = grpc_gcp_AltsContext_PeerAttributesEntry_value(
-        const_cast<grpc_gcp_AltsContext_PeerAttributesEntry*>(
-            peer_attributes_entry));
-    ASSERT_TRUE(upb_StringView_IsEqual(
-        key, upb_StringView_FromString(
-                 ALTS_TSI_HANDSHAKER_TEST_PEER_ATTRIBUTES_KEY)));
-    ASSERT_TRUE(upb_StringView_IsEqual(
-        val, upb_StringView_FromString(
-                 ALTS_TSI_HANDSHAKER_TEST_PEER_ATTRIBUTES_VALUE)));
-    peer_attributes_entry =
-        grpc_gcp_AltsContext_peer_attributes_nextmutable(ctx, &iter);
+
+  // TODO(b/397931390): Clean up the code after gRPC OSS migrates to proto
+  // v30.0.
+  const upb_Map* ctx_upb_map =
+      _grpc_gcp_AltsContext_peer_attributes_upb_map(ctx);
+  if (ctx_upb_map) {
+    size_t iter = kUpb_Map_Begin;
+    upb_MessageValue k, v;
+    while (upb_Map_Next(ctx_upb_map, &k, &v, &iter)) {
+      upb_StringView key = k.str_val;
+      upb_StringView val = v.str_val;
+      ASSERT_TRUE(upb_StringView_IsEqual(
+          key, upb_StringView_FromString(
+                   ALTS_TSI_HANDSHAKER_TEST_PEER_ATTRIBUTES_KEY)));
+      ASSERT_TRUE(upb_StringView_IsEqual(
+          val, upb_StringView_FromString(
+                   ALTS_TSI_HANDSHAKER_TEST_PEER_ATTRIBUTES_VALUE)));
+    }
   }
+
   // Validate security level.
   ASSERT_EQ(
       memcmp(ALTS_TSI_HANDSHAKER_TEST_SECURITY_LEVEL,
@@ -462,26 +464,26 @@ static void on_server_next_success_cb(tsi_result status, void* user_data,
   ASSERT_EQ(memcmp(ALTS_TSI_HANDSHAKER_TEST_LOCAL_IDENTITY, local_account.data,
                    local_account.size),
             0);
-  size_t iter = kUpb_Map_Begin;
-  grpc_gcp_AltsContext_PeerAttributesEntry* peer_attributes_entry =
-      grpc_gcp_AltsContext_peer_attributes_nextmutable(ctx, &iter);
-  ASSERT_NE(peer_attributes_entry, nullptr);
-  while (peer_attributes_entry != nullptr) {
-    upb_StringView key = grpc_gcp_AltsContext_PeerAttributesEntry_key(
-        const_cast<grpc_gcp_AltsContext_PeerAttributesEntry*>(
-            peer_attributes_entry));
-    upb_StringView val = grpc_gcp_AltsContext_PeerAttributesEntry_value(
-        const_cast<grpc_gcp_AltsContext_PeerAttributesEntry*>(
-            peer_attributes_entry));
-    ASSERT_TRUE(upb_StringView_IsEqual(
-        key, upb_StringView_FromString(
-                 ALTS_TSI_HANDSHAKER_TEST_PEER_ATTRIBUTES_KEY)));
-    ASSERT_TRUE(upb_StringView_IsEqual(
-        val, upb_StringView_FromString(
-                 ALTS_TSI_HANDSHAKER_TEST_PEER_ATTRIBUTES_VALUE)));
-    peer_attributes_entry =
-        grpc_gcp_AltsContext_peer_attributes_nextmutable(ctx, &iter);
+
+  // TODO(b/397931390): Clean up the code after gRPC OSS migrates to proto
+  // v30.0.
+  const upb_Map* ctx_upb_map =
+      _grpc_gcp_AltsContext_peer_attributes_upb_map(ctx);
+  if (ctx_upb_map) {
+    size_t iter = kUpb_Map_Begin;
+    upb_MessageValue k, v;
+    while (upb_Map_Next(ctx_upb_map, &k, &v, &iter)) {
+      upb_StringView key = k.str_val;
+      upb_StringView val = v.str_val;
+      ASSERT_TRUE(upb_StringView_IsEqual(
+          key, upb_StringView_FromString(
+                   ALTS_TSI_HANDSHAKER_TEST_PEER_ATTRIBUTES_KEY)));
+      ASSERT_TRUE(upb_StringView_IsEqual(
+          val, upb_StringView_FromString(
+                   ALTS_TSI_HANDSHAKER_TEST_PEER_ATTRIBUTES_VALUE)));
+    }
   }
+
   // Check security level.
   ASSERT_EQ(
       memcmp(ALTS_TSI_HANDSHAKER_TEST_SECURITY_LEVEL,
